Type: Package
Package: admiralmetabolic
Title: Metabolism Extension Package for ADaM in 'R' Asset Library
Version: 0.3.0
Authors@R: c(
    person("Anders", "Askeland", , "iakd@novonordisk.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-2996-129X")),
    person("Andrii", "Yurovskyi", , "andrii.yurovskyi@intego-group.com", role = "aut",
           comment = c(ORCID = "0009-0006-8606-0929")),
    person("Kathrin", "Flunkert", , "kathrin.flunkert@roche.com", role = "aut"),
    person("Edoardo", "Mancini", , "edoardo.mancini@roche.com", role = "aut",
           comment = c(ORCID = "0009-0006-4899-8641")),
    person("Shunsuke", "Goto", , "shunsuke.goto@novartis.com", role = "aut"),
    person("Siddhesh", "Pujari", , "spuj@novonordisk.com", role = "aut",
           comment = c(ORCID = "0009-0003-4971-1217")),
    person("Sonali", "Das", , "sxd@novonordisk.com", role = "aut"),
    person("Olga", "Starostecka", , "olga.starostecka@boehringer-ingelheim.com", role = "aut"),
    person("Vang", "Le-Quy", , "vqul@novonordisk.com", role = "aut",
           comment = c(ORCID = "0000-0003-2035-8619")),
    person("Keita", "Takahashi", , "keita.takahashi.4.biz@gmail.com", role = "aut",
           comment = c(ORCID = "0009-0004-9847-5115"))
  )
Description: A toolbox for programming Clinical Data Standards Interchange
    Consortium (CDISC) compliant Analysis Data Model (ADaM) datasets in R.
    ADaM datasets are a mandatory part of any New Drug or Biologics
    License Application submitted to the United States Food and Drug
    Administration (FDA). Analysis derivations are implemented in
    accordance with the "Analysis Data Model Implementation Guide" (CDISC
    Analysis Data Model Team, 2021,
    <https://www.cdisc.org/standards/foundational/adam>).  The package is
    an extension package of the 'admiral' package focusing on the
    metabolism therapeutic area.
License: Apache License (>= 2)
URL: https://pharmaverse.github.io/admiralmetabolic/,
        https://github.com/pharmaverse/admiralmetabolic
BugReports: https://github.com/pharmaverse/admiralmetabolic/issues
Depends: R (>= 4.1)
Imports: admiral (>= 1.1.1), admiraldev (>= 1.4.0), cli (>= 3.6.2),
        dplyr (>= 0.8.4), lifecycle (>= 0.1.0), lubridate (>= 1.7.4),
        magrittr (>= 1.5), purrr (>= 0.3.3), rlang (>= 0.4.4), stringr
        (>= 1.4.0), tidyselect (>= 1.0.0)
Suggests: diffdf, DT, htmltools, knitr, methods, pharmaversesdtm (>=
        1.3.0), rmarkdown, testthat (>= 3.0.0), tibble, usethis (>=
        2.2.3)
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-02-02 08:41:30 UTC; iakd
Author: Anders Askeland [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-2996-129X>),
  Andrii Yurovskyi [aut] (ORCID: <https://orcid.org/0009-0006-8606-0929>),
  Kathrin Flunkert [aut],
  Edoardo Mancini [aut] (ORCID: <https://orcid.org/0009-0006-4899-8641>),
  Shunsuke Goto [aut],
  Siddhesh Pujari [aut] (ORCID: <https://orcid.org/0009-0003-4971-1217>),
  Sonali Das [aut],
  Olga Starostecka [aut],
  Vang Le-Quy [aut] (ORCID: <https://orcid.org/0000-0003-2035-8619>),
  Keita Takahashi [aut] (ORCID: <https://orcid.org/0009-0004-9847-5115>)
Maintainer: Anders Askeland <iakd@novonordisk.com>
Repository: CRAN
Date/Publication: 2026-02-02 09:20:02 UTC
Built: R 4.6.0; ; 2026-04-25 13:32:54 UTC; unix
