---
title: "Get Started"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Get Started}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
```

# Introduction

As this is a package extension, if you are new to `{admiral}` then the best
place to first start reading would be the [Get
Started](https://pharmaverse.github.io/admiral/articles/admiral.html) page. This
extension package follows the same main idea and conventions, and re-uses many
functions from `{admiral}`, so it is important to thoroughly understand these to
be able to use `{admiralmetabolic}`.

# Derivations

The most important functions in `{admiralmetabolic}` are the
[derivations](https://pharmaverse.github.io/admiralmetabolic/reference/index.html). Again these follow the same
conventions as `{admiral}` but are focused to metabolism-specific needs.

# Creating ADaM Datasets

For the metabolic ADaM data structures, an overview of the flow and example function calls for the  most common steps are provided by the following vignettes:

- [Creating a Control of Eating Questionnaire ADaM](adcoeq.html)
- [Creating a Metabolic ADVS ADaM](advs.html)

`{admiralmetabolic}` also provides template R scripts as a starting point. They can be
created by calling `use_ad_template()` from `{admiral}`, e.g.,

```{r, eval = FALSE}
library(admiral)

use_ad_template(
  adam_name = "advs",
  save_path = "./ad_advs.R",
  package = "admiralmetabolic"
)
```

A list of all available templates from `{admiralmetabolic}` can be obtained by `list_all_templates()`
from `{admiral}`:

```{r, eval = FALSE}
list_all_templates(package = "admiralmetabolic")
```

# Support

Support is provided via [pharmaverse Slack](https://pharmaverse.slack.com/).
Additionally, please feel free to raise issues in our [GitHub repository](https://github.com/pharmaverse/admiralmetabolic/issues).
